@@ -1,4 +1,4 @@
-# Copyright 2001-2013, Paul Johnson (paul@pjcj.net)
+# Copyright 2001-2014, Paul Johnson (paul@pjcj.net)
 
 # This software is free.  It is licensed under the same terms as Perl itself.
 
@@ -10,7 +10,7 @@ package Devel::Cover::Branch;
 use strict;
 use warnings;
 
-our $VERSION = '1.08'; # VERSION
+our $VERSION = '1.17'; # VERSION
 
 use base "Devel::Cover::Criterion";
 
@@ -25,30 +25,25 @@ sub text        { $_[0][1]{text} }
 sub criterion   { 'branch' }
 
 
-sub percentage
-{
+sub percentage {
     my $t = $_[0]->total;
     sprintf "%3d", $t ? $_[0]->covered / $t * 100 : 0
 }
 
-sub error
-{
+sub error {
     my $self = shift;
-    if (@_)
-    {
+    if (@_) {
         my $c = shift;
         return !($self->covered($c) xor $self->uncoverable($c));
     }
     my $e = 0;
-    for my $c (0 .. $#{$self->[0]})
-    {
+    for my $c (0 .. $#{$self->[0]}) {
         $e++ if !($self->covered($c) xor $self->uncoverable($c));
     }
     $e
 }
 
-sub calculate_summary
-{
+sub calculate_summary {
     my $self = shift;
     my ($db, $file) = @_;
 
@@ -71,7 +66,7 @@ Devel::Cover::Branch - Code coverage metrics for Perl
 
 =head1 VERSION
 
-version 1.08
+version 1.17
 
 =head1 SYNOPSIS
 
@@ -93,7 +88,7 @@ Huh?
 
 =head1 LICENCE
 
-Copyright 2001-2013, Paul Johnson (paul@pjcj.net)
+Copyright 2001-2014, Paul Johnson (paul@pjcj.net)
 
 This software is free.  It is licensed under the same terms as Perl itself.
 
