@@ -1,4 +1,4 @@
-# Copyright 2011-2013, Paul Johnson (paul@pjcj.net)
+# Copyright 2011-2014, Paul Johnson (paul@pjcj.net)
 
 # This software is free.  It is licensed under the same terms as Perl itself.
 
@@ -12,26 +12,23 @@ use warnings;
 
 use Fcntl ":flock";
 
-our $VERSION = '1.08'; # VERSION
+our $VERSION = '1.17'; # VERSION
 
 my $Format;
 
-BEGIN
-{
+BEGIN {
     $Format = "JSON"     if              eval "use JSON; 1";
     $Format = "JSON::PP" if !$Format and eval "use JSON::PP; 1";
     die "Can't load either JSON or JSON::PP" unless $Format;
 }
 
-sub new
-{
+sub new {
     my $class = shift;
-    my $self  = { @_ };
+    my $self  = { options => "", @_ };
     bless $self, $class
 }
 
-sub read
-{
+sub read {
     my $self   = shift;
     my ($file) = @_;
 
@@ -49,8 +46,7 @@ sub read
     $data
 }
 
-sub write
-{
+sub write {
     my $self = shift;
     my ($data, $file) = @_;
 
@@ -74,7 +70,7 @@ Devel::Cover::DB::IO::JSON - JSON based IO routines for Devel::Cover::DB
 
 =head1 VERSION
 
-version 1.08
+version 1.17
 
 =head1 SYNOPSIS
 
@@ -118,7 +114,7 @@ Huh?
 
 =head1 LICENCE
 
-Copyright 2011-2013, Paul Johnson (paul@pjcj.net)
+Copyright 2011-2014, Paul Johnson (paul@pjcj.net)
 
 This software is free.  It is licensed under the same terms as Perl itself.
 
