@@ -1,4 +1,4 @@
-# Copyright 2001-2013, Paul Johnson (paul@pjcj.net)
+# Copyright 2001-2014, Paul Johnson (paul@pjcj.net)
 
 # This software is free.  It is licensed under the same terms as Perl itself.
 
@@ -10,7 +10,7 @@ package Devel::Cover::Pod;
 use strict;
 use warnings;
 
-our $VERSION = '1.08'; # VERSION
+our $VERSION = '1.17'; # VERSION
 
 use base "Devel::Cover::Criterion";
 
@@ -23,8 +23,7 @@ sub percentage  { $_[0][0] ? 100 : 0 }
 sub error       { $_[0][0] xor !$_[0][2] }
 sub criterion   { 'pod' }
 
-sub calculate_summary
-{
+sub calculate_summary {
     my $self = shift;
     my ($db, $file) = @_;
 
@@ -48,7 +47,7 @@ Devel::Cover::Pod - Code coverage metrics for Perl
 
 =head1 VERSION
 
-version 1.08
+version 1.17
 
 =head1 SYNOPSIS
 
@@ -70,7 +69,7 @@ Huh?
 
 =head1 LICENCE
 
-Copyright 2001-2013, Paul Johnson (paul@pjcj.net)
+Copyright 2001-2014, Paul Johnson (paul@pjcj.net)
 
 This software is free.  It is licensed under the same terms as Perl itself.
 
