@@ -2,7 +2,7 @@ package Devel::Cover::Report::Html_subtle;
 use strict;
 use warnings;
 
-our $VERSION = '1.08'; # VERSION
+our $VERSION = '1.17'; # VERSION
 
 use Devel::Cover::DB;
 use Devel::Cover::Html_Common "launch";
@@ -16,8 +16,7 @@ my $Template;
 my %Filenames;
 my %File_exists;
 
-sub get_options
-{
+sub get_options {
     my ($self, $opt) = @_;
     $opt->{option}{outputfile} = "coverage.html";
     die "Invalid command line options" unless
@@ -77,8 +76,9 @@ sub print_summary {
         my $part = $db->{summary}{$file};
         for my $criterion (@showing) {
             my $pc = exists $part->{$criterion}
-            ? sprintf "%4.1f", $part->{$criterion}{percentage}
-            : "n/a";
+                ? do { my $x = sprintf "%5.2f", $part->{$criterion}{percentage};
+                       chop $x; $x }
+                : "n/a";
 
             if ($pc ne 'n/a') {
                 if ($criterion ne 'time') {
@@ -87,11 +87,9 @@ sub print_summary {
                 if (exists $Filenames{$file}) {
                     if ($criterion eq 'branch') {
                         $vals{$file}{$criterion}{link} = "$Filenames{$file}--branch.html";
-                    }
-                    elsif ($criterion eq 'condition') {
+                    } elsif ($criterion eq 'condition') {
                         $vals{$file}{$criterion}{link} = "$Filenames{$file}--condition.html";
-                    }
-                    elsif ($criterion eq 'subroutine') {
+                    } elsif ($criterion eq 'subroutine') {
                         $vals{$file}{$criterion}{link} = "$Filenames{$file}--subroutine.html";
                     }
                 }
@@ -183,25 +181,20 @@ sub print_file {
                     link  => "$Filenames{$file}--branch.html#line$."};
                 }
                 push @{$line{metrics}}, \@p;
-            }
-            elsif ($c eq 'condition') {
+            } elsif ($c eq 'condition') {
                 my @tt = $file_data->condition->truth_table($.);
                 my @p;
-                if (@tt)
-                {
+                if (@tt) {
                     foreach (@tt) {
                         push @p, {text  => sprintf("%.0f", $_->[0]->percentage),
                         class => cvg_class($_->[0]->percentage),
                         link  => "$Filenames{$file}--condition.html#line$."};
                     }
-                }
-                else
-                {
+                } else {
                     push @p, { text => "expression contains > 16 terms: ignored" };
                 }
                 push @{$line{metrics}}, \@p;
-            }
-            elsif ($c eq 'subroutine') {
+            } elsif ($c eq 'subroutine') {
                 my @p;
                 while (my $o = shift @{$metric{$c}}) {
                     push @p, {text  => $o->covered,
@@ -209,8 +202,7 @@ sub print_file {
                     link  => "$Filenames{$file}--subroutine.html#line$."};
                 }
                 push @{$line{metrics}}, \@p;
-            }
-            else {
+            } else {
                 my @p;
                 while (my $o = shift @{$metric{$c}}) {
                     push @p, {text  => ($c =~ /statement|pod|time/) ? $o->covered : $o->percentage,
@@ -337,11 +329,9 @@ sub print_subroutines {
     return unless $subroutines;
 
     my @data;
-    for my $location ($subroutines->items)
-    {
+    for my $location ($subroutines->items) {
         my $l = $subroutines->location($location);
-        for my $sub (@$l)
-        {
+        for my $sub (@$l) {
             push @data, {
                 ref   => "line$location",
                 line  => $location,
@@ -399,7 +389,7 @@ package Devel::Cover::Report::Html_subtle::Template::Provider;
 use strict;
 use warnings;
 
-our $VERSION = '1.08'; # VERSION
+our $VERSION = '1.17'; # VERSION
 
 use base "Template::Provider";
 
@@ -718,7 +708,7 @@ Devel::Cover::Report::Html_subtle - HTML backend for Devel::Cover
 
 =head1 VERSION
 
-version 1.08
+version 1.17
 
 =head1 SYNOPSIS
 
@@ -742,7 +732,7 @@ Huh?
 
 =head1 LICENCE
 
-Copyright 2001-2013, Paul Johnson (paul@pjcj.net)
+Copyright 2001-2014, Paul Johnson (paul@pjcj.net)
 
 This software is free.  It is licensed under the same terms as Perl itself.
 
